﻿using Infragistics.Controls.Charts;
using System.Collections;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Windows;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Shapes;
using Infragistics.Controls.Menus;
using ContextMenuService = Infragistics.Controls.Menus.ContextMenuService;

namespace WpfApplication1
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        FamilyTreeViewModel viewmodel = new FamilyTreeViewModel();
        public MainWindow()
        {
            InitializeComponent();
        }

        private void Diagram_SelectionChanged(object sender, Infragistics.Controls.Charts.DiagramSelectionChangedEventArgs e)
        {                        
            if (e.AddedItems.Count() > 0 && e.AddedItems[0] is DiagramItem)
            {
                ObservableCollection<Person> personCollection = viewmodel.FamilyTree;

                Person item = e.AddedItems[0].Content as Person;

                if (item == null) return;

                DiagramToolboxCategoryCollection customCategoryCollection = new DiagramToolboxCategoryCollection();
               
                DiagramToolboxCategory Parents = new DiagramToolboxCategory();        
               
                    if (item.Relation == "Mother" || item.Relation == "Father")
                    {
                        customCategoryCollection.Add(Parents);
                         toolbox.CustomCategories.Add(customCategoryCollection[0]);
                    DiagramToolboxItem toolboxItem = new DiagramToolboxItem();
                   
                    customCategoryCollection[0].Items.Add(toolboxItem);
                    DiagramNode node = new DiagramNode();

                    PathFigure myPathFigure = new PathFigure();
                    myPathFigure.StartPoint = new Point(10, 50);

                    LineSegment myLineSegment = new LineSegment();
                    myLineSegment.Point = new Point(200, 70);

                    PathSegmentCollection myPathSegmentCollection = new PathSegmentCollection();
                    myPathSegmentCollection.Add(myLineSegment);

                    myPathFigure.Segments = myPathSegmentCollection;

                    PathFigureCollection myPathFigureCollection = new PathFigureCollection();
                    myPathFigureCollection.Add(myPathFigure);

                    PathGeometry myPathGeometry = new PathGeometry();
                    myPathGeometry.Figures = myPathFigureCollection;

                    Path myPath = new Path();
                    myPath.Stroke = Brushes.Black;
                    myPath.StrokeThickness = 1;
                    myPath.Data = myPathGeometry;

                    node.Geometry = myPathGeometry;

                    toolboxItem.Item = node;

                }
                    else
                    {
                        customCategoryCollection.Clear();
                        if (toolbox.CustomCategories.Count() > 0)
                        {
                            toolbox.CustomCategories.RemoveAt(0);
                        }                      
                }        
            }            
        }

        private void DiagramNodeOnRightClick(object sender, MouseButtonEventArgs e)
        {
            Diagram.SelectedItems.Clear();
            (sender as DiagramNode).IsSelected = true;
        }

        private void OnContextMenuOpening(object sender, OpeningEventArgs e)
        {
            if (Diagram.SelectedItems[0] != null)
            {
                ContextMenuManager contexntMenuManager = null;
                if (Diagram != null) contexntMenuManager = ContextMenuService.GetManager(Diagram);
                if (contexntMenuManager != null)
                {
                    contexntMenuManager.ContextMenu.Items.Clear();
                    var p = Diagram.SelectedItems[0].Content as Person;
                    if (p.Relation == "Father" || p.Relation == "Mother")
                    {
                        contexntMenuManager.ContextMenu.Items.Add(new XamMenuItem() { Header = "Add Child" });
                    }
                    if (p.Relation == "Me" )
                    {
                        contexntMenuManager.ContextMenu.Items.Add(new XamMenuItem() { Header = "Add Sibling" });
                    }
                }
            }
            else
            {
                e.Cancel = true;
            }
        }
    }


    public class FamilyTreeViewModel : INotifyPropertyChanged
    {
        ObservableCollection<Person> _familyTree;
        public ObservableCollection<Person> FamilyTree
        {
            get { return _familyTree; }
            set
            {
                _familyTree = value;
                OnPropertyChanged("FamilyTree");
            }
        }

        public FamilyTreeViewModel()
        {
            var me = new Person(1, "Me", "John", "GUY04.jpg");
            var dad = new Person(2, "Father", "James", "GUY20.jpg") { Children = new List<int>() { 1 } };
            var mom = new Person(3, "Mother", "Jane", "GIRL15.jpg") { Children = new List<int>() { 1 } };
            //var grandpa = new Person(4, DiagramStrings.FamiliyTree_Grandfather, DiagramStrings.FamilyTree_Steve, "GUY19.jpg") { Children = new List<int>() { 2 } };
            //var grandma = new Person(5, DiagramStrings.FamiliyTree_Grandfather, DiagramStrings.FamilyTree_William, "GUY05.jpg") { Children = new List<int>() { 3 } };

            //var wife = new Person(6, DiagramStrings.FamiliyTree_Wife, DiagramStrings.FamilyTree_Christine, "GIRL28.jpg") { Children = new List<int>() { 1 } };
            //var herdad = new Person(7, DiagramStrings.FamiliyTree_Father, DiagramStrings.FamilyTree_Charles, "GUY01.jpg") { Children = new List<int>() { 6 } };
            //var hermom = new Person(8, DiagramStrings.FamiliyTree_Mother, DiagramStrings.FamilyTree_Maria, "GIRL29.jpg") { Children = new List<int>() { 6 } };
            //var hergrandpa = new Person(9, DiagramStrings.FamiliyTree_Grandfather, DiagramStrings.FamilyTree_Bob, "GUY09.jpg") { Children = new List<int>() { 7 } };
            //var hergrandma = new Person(10, DiagramStrings.FamiliyTree_Grandmother, DiagramStrings.FamilyTree_Eve, "GIRL22.jpg") { Children = new List<int>() { 7 } };

            FamilyTree = new ObservableCollection<Person>();
            FamilyTree.Add(me);
            FamilyTree.Add(dad);
            FamilyTree.Add(mom);
            //FamilyTree.Add(grandpa);
            //FamilyTree.Add(grandma);
            //FamilyTree.Add(wife);
            //FamilyTree.Add(herdad);
            //FamilyTree.Add(hermom);
            //FamilyTree.Add(hergrandpa);
            //FamilyTree.Add(hergrandma);
        }

        public event PropertyChangedEventHandler PropertyChanged;
        void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
    }

    public class Person : INotifyPropertyChanged
    {
        public Person(int id, string relation, string name, string path)
        {
            Id = id;
            Relation = relation;
            Name = name;
            //ImagePath = ImageFilePathProvider.GetImageLocalPath() + "people/" + path;
        }

        int _id;
        public int Id
        {
            get { return _id; }
            set
            {
                _id = value;
                OnPropertyChanged("Id");
            }
        }

        string _name;
        public string Name
        {
            get { return _name; }
            set
            {
                _name = value;
                OnPropertyChanged("Name");
            }
        }

        string _relation;
        public string Relation
        {
            get { return _relation; }
            set
            {
                _relation = value;
                OnPropertyChanged("Relation");
            }
        }

        string _path;
        public string ImagePath
        {
            get { return _path; }
            set
            {
                _path = value;
                OnPropertyChanged("ImagePath");
            }
        }

        IList _children;
        public IList Children
        {
            get { return _children; }
            set
            {
                _children = value;
                OnPropertyChanged("Children");
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
        void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
        }
    }
}
